@@ -553,7 +553,7 @@ class Douglas_peucker(object):
             pointlist[i] = self.DouglasPeucker(pointlist[i], self.EPSILON)
         handwritten_data.set_pointlist(pointlist)
         # This might have duplicated points! Filter them!
-        handwritten_data.preprocessing([Remove_points()])
+        handwritten_data.preprocessing([Remove_duplicate_time()])
 
 
 class Stroke_connect(object):
